@@ -1,12 +1,15 @@
 """Contains a collection of helper functions to manipulate strings.
+
+This module is less concerned with bytes/unicode and text processing, compared with text.py
 """
+from __future__ import annotations
 from enum import unique, Enum, auto
-from typing import List, Union
+from collections.abc import Iterable
 
 
-def collapse(*args: Union[str, List[str]], separate: str = '', surround: str = '') -> str:
-    """Takes a list of strings and concatenates them, separating each string with the value of `separate` and
-    surrounding each string with the value of `surround`.
+def collapse(*args: str | Iterable[str], separate: str = '', surround: str = '') -> str:
+    """Takes a list of strings and concatenates them, separating each string with the value of
+    `separate` and surrounding each string with the value of `surround`.
 
     Args:
         *args:
@@ -19,7 +22,7 @@ def collapse(*args: Union[str, List[str]], separate: str = '', surround: str = '
     Returns:
         string surrounded by `surround` and separated by `separate`
     """
-    if len(args) == 1 and isinstance(args[0], list):
+    if len(args) == 1 and isinstance(args[0], Iterable):
         args = args[0]
 
     return separate.join([surround + x + surround for x in args])
@@ -40,7 +43,8 @@ class RoundTo(Enum):
 def format_number(value: float,
                   granularity: RoundTo = RoundTo.AUTO,
                   places: int = 2) -> str:
-    """Formats numbers in a way that humans would typically want to see at a glance (e.g. on a graph.)
+    """Formats numbers in a way that humans would typically want to see at a glance (e.g. on a
+    graph.)
 
     For example, `123560000` is transformed to `123.56M`
 
@@ -57,12 +61,16 @@ def format_number(value: float,
         places: the number of digits to the right of the decimal to display. (default is `2`)
 
             For example:
-                `format_number(123567000, granularity=RoundTo.MILLIONS, num_digits=2)` -> '123.57M'
-                `format_number(123567000, granularity=RoundTo.MILLIONS, num_digits=3)` -> '123.567M'
+
+            `format_number(123567000, granularity=RoundTo.MILLIONS, num_digits=2)` -> '123.57M'
+            `format_number(123567000, granularity=RoundTo.MILLIONS, num_digits=3)` -> '123.567M'
 
     Returns:
         the formatted number as a string
     """
+    if value == 0:
+        return '0'
+
     granularity_lookup = {
         RoundTo.THOUSANDS: 1000,
         RoundTo.MILLIONS: 1000000,
